#include <glib.h>
#include <stdio.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>

#include "utils.h"

char *script_path = "/tmp/csd_hd_helper.sh";
char *hd_helper_text = 
"#! /bin/bash\n"
"fdisk -l | sed -n '/^\\/dev/p'  | awk '{print $1}' | \n"
"while read line\n"
"do\n"
"	$1 $line\n"
"done\n";

gboolean create_hd_helper_script ()
{
    FILE *file;
    int len;

    file = fopen (script_path,  "w");
    if (!file) {
        g_warning ("failed to open script: %s", script_path);
        return FALSE;
    }

    len = strlen (hd_helper_text);
    if (len != fwrite (hd_helper_text, sizeof(char), len, file)) {
        g_warning ("failed to write hard disk helper script: %s", hd_helper_text);
        return FALSE;
    }
    chmod (script_path, S_IXUSR | S_IWUSR);
    fclose (file);
    return TRUE;
}

void set_mode (gchar *cmd)
{
    gchar  *stdout_data = NULL;
    GError *error = NULL;
    gint exit_status;
    gchar *argv[3] = {0};

    argv[0] = script_path;
    argv[1] = cmd;

    g_spawn_sync (NULL,
		    argv,
		    get_helper_environ (),
		    G_SPAWN_SEARCH_PATH,
		    NULL,
		    NULL,
		    &stdout_data,
		    NULL,
		    &exit_status,
		    &error);

    g_debug ("set_mode stdout_data: %s  exit_status: %d", stdout_data, exit_status);

    if (exit_status != 0)
    {
        g_warning ("failed to set hard disk run mode");
    }

    if (error)
    {
        g_warning ("%s", error->message);
        g_clear_error (&error);
    }
}

int main(int argc, char *argv[])
{
    gchar *cmd;

    if (argc != 2)
    {
        g_warning("Please input right parameter");
        return -1;
    }

    if (g_strcmp0 (argv[1], "savepower") == 0)
    {
        // 打开N7 NVMe ASPT
        // https://phisonblog.com/best-practices-in-nvme-power-management-tradeoff-between-power-savings-and-latency-in-an-ssd-2/
        cmd = g_strdup_printf ("nvme set-feature -f 0x0c -v 1 ");
    }
    else if (g_strcmp0 (argv[1], "other") == 0)
    {
        // 关闭N7 NVMe ASPT
        cmd = g_strdup_printf ("nvme set-feature -f 0x0c -v 0 ");
    }
    else
    {
        g_warning ("Please input right paramenter");
        return -1;
    }
    
    if (!create_hd_helper_script ())
        return -1;

    set_mode (cmd);
    if (access (script_path, F_OK))
        remove (script_path);

    g_free (cmd);
    return 0;
}

