#include "utils.h"

#include <glib/gi18n.h>

/**
 * cdos_util_spawn_command_line:
 * @command_line: 需要执行的命令字符串
 *
 * 在后台执行命令行操作命令，如果执行异常，则自行处理。
 *
 * Returns:返回对应的进程PID
 */
gint
cdos_util_spawn_command_line (const gchar *command_line)
{
    GPid pid;
    GError *error = NULL;
    gint argcp;
    gchar **argvp;

    g_shell_parse_argv (command_line, &argcp, &argvp, &error);
    if (error)
    {
        g_warning ("Warnings:%s-->%s", __func__, error->message);
        g_error_free (error);
        return 0;
    }

    g_spawn_async (NULL, argvp, NULL, G_SPAWN_SEARCH_PATH |
                   G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
                   NULL, NULL, &pid, &error);
    if(error)
    {
        g_warning ("Warnings:%s-->%s", __func__, error->message);
        g_error_free (error);
        return 0;
    }
    g_strfreev (argvp);
    return pid;
}


// 低电量通知
void notify_low_battery(const gchar *icon_name, const char *msg)
{
        gchar *notify_low = g_strconcat ("notify-send -i ", icon_name, " ", _("Low Power Notification"), " ", msg, NULL);
        cdos_util_spawn_command_line (notify_low);
        g_free (notify_low);
}

// 获取命令运行环境
gchar **
get_helper_environ (void)
{
        static gchar **environ = NULL;

        if (environ)
                return environ;

        environ = g_environ_unsetenv (g_get_environ (), "SHELL");
        return environ;
}

// 查找键盘背光设备
gchar *
get_kbd_backlight_dir_path ()
{
	GDir *dir;
	const gchar *filename;
	gchar *dir_path = NULL;
	GError *error = NULL;

	// 查找leds设备
	dir = g_dir_open ("/sys/class/leds", 0, &error);
	if (dir == NULL) {
		if (!g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT)) {
			g_warning ("failed to open directory: %s", error->message);
			g_error_free (error);
		}
		return dir_path;
	}

	// 查找键盘背光
	while ((filename = g_dir_read_name (dir)) != NULL) {
		if (g_strstr_len (filename, -1, "kbd_backlight") != NULL) {
			dir_path = g_build_filename ("/sys/class/leds",
						    filename, NULL);
			break;
		}
	}

	g_dir_close (dir);
	return dir_path;
}