/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Suite 500, Boston, MA 02110-1335, USA.
 *
 */

#include "config.h"

#include <glib/gi18n-lib.h>
#include <gmodule.h>

#include "cdos-settings-plugin.h"
#include "csd-xsettings-plugin.h"
#include "csd-xsettings-manager.h"

struct CdosSettingsXSettingsPluginPrivate {
        CdosSettingsXSettingsManager *manager;
};

#define CDOS_XSETTINGS_PLUGIN_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), CDOS_TYPE_XSETTINGS_PLUGIN, CdosSettingsXSettingsPluginPrivate))

CDOS_SETTINGS_PLUGIN_REGISTER (CdosSettingsXSettingsPlugin, cdos_xsettings_plugin)

static void
cdos_xsettings_plugin_init (CdosSettingsXSettingsPlugin *plugin)
{
        plugin->priv = CDOS_XSETTINGS_PLUGIN_GET_PRIVATE (plugin);

        g_debug ("CdosSettingsXSettingsPlugin initializing");

        plugin->priv->manager = cdos_xsettings_manager_new ();
}

static void
cdos_xsettings_plugin_finalize (GObject *object)
{
        CdosSettingsXSettingsPlugin *plugin;

        g_return_if_fail (object != NULL);
        g_return_if_fail (CDOS_IS_XSETTINGS_PLUGIN (object));

        g_debug ("CdosSettingsXSettingsPlugin finalizing");

        plugin = CDOS_XSETTINGS_PLUGIN (object);

        g_return_if_fail (plugin->priv != NULL);

        if (plugin->priv->manager != NULL) {
                g_object_unref (plugin->priv->manager);
        }

        G_OBJECT_CLASS (cdos_xsettings_plugin_parent_class)->finalize (object);
}

static void
impl_activate (CdosSettingsPlugin *plugin)
{
        gboolean res;
        GError  *error;

        g_debug ("Activating xsettings plugin");

        error = NULL;
        res = cdos_xsettings_manager_start (CDOS_XSETTINGS_PLUGIN (plugin)->priv->manager, &error);
        if (! res) {
                g_warning ("Unable to start xsettings manager: %s", error->message);
                g_error_free (error);
        }
}

static void
impl_deactivate (CdosSettingsPlugin *plugin)
{
        g_debug ("Deactivating xsettings plugin");
        cdos_xsettings_manager_stop (CDOS_XSETTINGS_PLUGIN (plugin)->priv->manager);
}

static void
cdos_xsettings_plugin_class_init (CdosSettingsXSettingsPluginClass *klass)
{
        GObjectClass             *object_class = G_OBJECT_CLASS (klass);
        CdosSettingsPluginClass *plugin_class = CDOS_SETTINGS_PLUGIN_CLASS (klass);

        object_class->finalize = cdos_xsettings_plugin_finalize;

        plugin_class->activate = impl_activate;
        plugin_class->deactivate = impl_deactivate;

        g_type_class_add_private (klass, sizeof (CdosSettingsXSettingsPluginPrivate));
}
